package com.os.ems.record.service.impl;

import java.util.List;
import com.os.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.ems.record.mapper.EmsRecordAlarmDataMapper;
import com.os.ems.record.domain.EmsRecordAlarmData;
import com.os.ems.record.service.IEmsRecordAlarmDataService;

/**
 * 异常数据记录Service业务层处理
 * 
 * @author Yinq
 * @date 2024-05-15
 */
@Service
public class EmsRecordAlarmDataServiceImpl implements IEmsRecordAlarmDataService 
{
    @Autowired
    private EmsRecordAlarmDataMapper emsRecordAlarmDataMapper;

    /**
     * 查询异常数据记录
     * 
     * @param objId 异常数据记录主键
     * @return 异常数据记录
     */
    @Override
    public EmsRecordAlarmData selectEmsRecordAlarmDataByObjId(Long objId)
    {
        return emsRecordAlarmDataMapper.selectEmsRecordAlarmDataByObjId(objId);
    }

    /**
     * 查询异常数据记录列表
     * 
     * @param emsRecordAlarmData 异常数据记录
     * @return 异常数据记录
     */
    @Override
    public List<EmsRecordAlarmData> selectEmsRecordAlarmDataList(EmsRecordAlarmData emsRecordAlarmData)
    {
        return emsRecordAlarmDataMapper.selectEmsRecordAlarmDataList(emsRecordAlarmData);
    }

    /**
     * 新增异常数据记录
     * 
     * @param emsRecordAlarmData 异常数据记录
     * @return 结果
     */
    @Override
    public int insertEmsRecordAlarmData(EmsRecordAlarmData emsRecordAlarmData)
    {
        emsRecordAlarmData.setCreateTime(DateUtils.getNowDate());
        return emsRecordAlarmDataMapper.insertEmsRecordAlarmData(emsRecordAlarmData);
    }

    /**
     * 修改异常数据记录
     * 
     * @param emsRecordAlarmData 异常数据记录
     * @return 结果
     */
    @Override
    public int updateEmsRecordAlarmData(EmsRecordAlarmData emsRecordAlarmData)
    {
        emsRecordAlarmData.setUpdateTime(DateUtils.getNowDate());
        return emsRecordAlarmDataMapper.updateEmsRecordAlarmData(emsRecordAlarmData);
    }

    /**
     * 批量删除异常数据记录
     * 
     * @param objIds 需要删除的异常数据记录主键
     * @return 结果
     */
    @Override
    public int deleteEmsRecordAlarmDataByObjIds(Long[] objIds)
    {
        return emsRecordAlarmDataMapper.deleteEmsRecordAlarmDataByObjIds(objIds);
    }

    /**
     * 删除异常数据记录信息
     * 
     * @param objId 异常数据记录主键
     * @return 结果
     */
    @Override
    public int deleteEmsRecordAlarmDataByObjId(Long objId)
    {
        return emsRecordAlarmDataMapper.deleteEmsRecordAlarmDataByObjId(objId);
    }
}
