package com.os.mes.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.base.domain.BaseCustomData;
import com.os.mes.base.service.IBaseCustomDataService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 自定义数据维护Controller
 *
 * @author Yinq
 * @date 2024-05-10
 */
@RestController
@RequestMapping("/mes/base/baseCustomData")
public class BaseCustomDataController extends BaseController {
    @Autowired
    private IBaseCustomDataService baseCustomDataService;

    /**
     * 查询自定义数据维护列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseCustomData:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseCustomData baseCustomData) {
        startPage();
        List<BaseCustomData> list = baseCustomDataService.selectBaseCustomDataList(baseCustomData);
        return getDataTable(list);
    }

    /**
     * 导出自定义数据维护列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseCustomData:export')")
    @Log(title = "自定义数据维护", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseCustomData baseCustomData) {
        List<BaseCustomData> list = baseCustomDataService.selectBaseCustomDataList(baseCustomData);
        ExcelUtil<BaseCustomData> util = new ExcelUtil<BaseCustomData>(BaseCustomData.class);
        util.exportExcel(response, list, "自定义数据维护数据");
    }

    /**
     * 获取自定义数据维护详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseCustomData:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(baseCustomDataService.selectBaseCustomDataByObjId(objId));
    }

    /**
     * 新增自定义数据维护
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseCustomData:add')")
    @Log(title = "自定义数据维护", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseCustomData baseCustomData) {
        baseCustomData.setCreateBy(getUsername());
        return toAjax(baseCustomDataService.insertBaseCustomData(baseCustomData));
    }

    /**
     * 修改自定义数据维护
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseCustomData:edit')")
    @Log(title = "自定义数据维护", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseCustomData baseCustomData) {
        baseCustomData.setUpdateBy(getUsername());
        return toAjax(baseCustomDataService.updateBaseCustomData(baseCustomData));
    }

    /**
     * 删除自定义数据维护
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseCustomData:remove')")
    @Log(title = "自定义数据维护", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(baseCustomDataService.deleteBaseCustomDataByObjIds(objIds));
    }
}
