package com.os.mes.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.base.domain.BaseProcessInfo;
import com.os.mes.base.service.IBaseProcessInfoService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 工序信息Controller
 *
 * @author Yinq
 * @date 2024-05-23
 */
@RestController
@RequestMapping("/mes/base/processInfo")
public class BaseProcessInfoController extends BaseController {
    @Autowired
    private IBaseProcessInfoService baseProcessInfoService;

    /**
     * 查询工序信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:processInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseProcessInfo baseProcessInfo) {
        startPage();
        List<BaseProcessInfo> list = baseProcessInfoService.selectBaseProcessInfoList(baseProcessInfo);
        return getDataTable(list);
    }

    /**
     * 导出工序信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:processInfo:export')")
    @Log(title = "工序信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseProcessInfo baseProcessInfo) {
        List<BaseProcessInfo> list = baseProcessInfoService.selectBaseProcessInfoList(baseProcessInfo);
        ExcelUtil<BaseProcessInfo> util = new ExcelUtil<BaseProcessInfo>(BaseProcessInfo.class);
        util.exportExcel(response, list, "工序信息数据");
    }

    /**
     * 获取工序信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:processInfo:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(baseProcessInfoService.selectBaseProcessInfoByObjId(objId));
    }

    /**
     * 新增工序信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:processInfo:add')")
    @Log(title = "工序信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseProcessInfo baseProcessInfo) {
        baseProcessInfo.setCreateBy(getUsername());
        return toAjax(baseProcessInfoService.insertBaseProcessInfo(baseProcessInfo));
    }

    /**
     * 修改工序信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:processInfo:edit')")
    @Log(title = "工序信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseProcessInfo baseProcessInfo) {
        baseProcessInfo.setUpdateBy(getUsername());
        return toAjax(baseProcessInfoService.updateBaseProcessInfo(baseProcessInfo));
    }

    /**
     * 删除工序信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:processInfo:remove')")
    @Log(title = "工序信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(baseProcessInfoService.deleteBaseProcessInfoByObjIds(objIds));
    }
}
