package com.os.mes.base.service.impl;

import java.util.List;

import com.os.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.base.mapper.BaseStaffInfoMapper;
import com.os.mes.base.domain.BaseStaffInfo;
import com.os.mes.base.service.IBaseStaffInfoService;

/**
 * 员工信息Service业务层处理
 *
 * @author Yinq
 * @date 2024-05-15
 */
@Service
public class BaseStaffInfoServiceImpl implements IBaseStaffInfoService {
    @Autowired
    private BaseStaffInfoMapper baseStaffInfoMapper;

    /**
     * 查询员工信息
     *
     * @param objId 员工信息主键
     * @return 员工信息
     */
    @Override
    public BaseStaffInfo selectBaseStaffInfoByObjId(Long objId) {
        return baseStaffInfoMapper.selectBaseStaffInfoByObjId(objId);
    }

    /**
     * 查询员工信息列表
     *
     * @param baseStaffInfo 员工信息
     * @return 员工信息
     */
    @Override
    public List<BaseStaffInfo> selectBaseStaffInfoList(BaseStaffInfo baseStaffInfo) {
        return baseStaffInfoMapper.selectBaseStaffInfoList(baseStaffInfo);
    }

    /**
     * 新增员工信息
     *
     * @param baseStaffInfo 员工信息
     * @return 结果
     */
    @Override
    public int insertBaseStaffInfo(BaseStaffInfo baseStaffInfo) {
        baseStaffInfo.setCreateTime(DateUtils.getNowDate());
        return baseStaffInfoMapper.insertBaseStaffInfo(baseStaffInfo);
    }

    /**
     * 修改员工信息
     *
     * @param baseStaffInfo 员工信息
     * @return 结果
     */
    @Override
    public int updateBaseStaffInfo(BaseStaffInfo baseStaffInfo) {
        baseStaffInfo.setUpdateTime(DateUtils.getNowDate());
        return baseStaffInfoMapper.updateBaseStaffInfo(baseStaffInfo);
    }

    /**
     * 批量删除员工信息
     *
     * @param objIds 需要删除的员工信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseStaffInfoByObjIds(Long[] objIds) {
        for (Long objId : objIds) {
            BaseStaffInfo baseStaffInfo = baseStaffInfoMapper.selectBaseStaffInfoByObjId(objId);
            baseStaffInfo.setDelFlag("2");
            baseStaffInfoMapper.updateBaseStaffInfo(baseStaffInfo);
        }
        return 1;
    }

    /**
     * 删除员工信息信息
     *
     * @param objId 员工信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseStaffInfoByObjId(Long objId) {
        BaseStaffInfo baseStaffInfo = baseStaffInfoMapper.selectBaseStaffInfoByObjId(objId);
        baseStaffInfo.setDelFlag("2");
        return baseStaffInfoMapper.updateBaseStaffInfo(baseStaffInfo);
    }
}
