package com.os.mes.prod.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.prod.domain.ProdOrderInfo;
import com.os.mes.prod.service.IProdOrderInfoService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 订单信息Controller
 *
 * @author Yinq
 * @date 2024-05-17
 */
@RestController
@RequestMapping("/mes/prod/prodOrderInfo")
public class ProdOrderInfoController extends BaseController {
    @Autowired
    private IProdOrderInfoService prodOrderInfoService;

    /**
     * 查询订单信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdOrderInfo prodOrderInfo) {
        startPage();
        List<ProdOrderInfo> list = prodOrderInfoService.selectProdOrderInfoList(prodOrderInfo);
        return getDataTable(list);
    }

    /**
     * 导出订单信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderInfo:export')")
    @Log(title = "订单信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdOrderInfo prodOrderInfo) {
        List<ProdOrderInfo> list = prodOrderInfoService.selectProdOrderInfoList(prodOrderInfo);
        ExcelUtil<ProdOrderInfo> util = new ExcelUtil<ProdOrderInfo>(ProdOrderInfo.class);
        util.exportExcel(response, list, "订单信息数据");
    }

    /**
     * 获取订单信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderInfo:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodOrderInfoService.selectProdOrderInfoByObjId(objId));
    }

    /**
     * 新增订单信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderInfo:add')")
    @Log(title = "订单信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdOrderInfo prodOrderInfo) {
        prodOrderInfo.setCreateBy(getUsername());
        return toAjax(prodOrderInfoService.insertProdOrderInfo(prodOrderInfo));
    }

    /**
     * 修改订单信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderInfo:edit')")
    @Log(title = "订单信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdOrderInfo prodOrderInfo) {
        prodOrderInfo.setUpdateBy(getUsername());
        return toAjax(prodOrderInfoService.updateProdOrderInfo(prodOrderInfo));
    }

    /**
     * 删除订单信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodOrderInfo:remove')")
    @Log(title = "订单信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodOrderInfoService.deleteProdOrderInfoByObjIds(objIds));
    }
}
