package com.os.mes.prod.domain;

import java.util.Date;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.os.common.annotation.Excel;
import com.os.common.core.domain.BaseEntity;

/**
 * 订单信息对象 prod_order_info
 *
 * @author Yinq
 * @date 2024-05-17
 */
public class ProdOrderInfo extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 主键标识
     */
    private Long objId;

    /**
     * 订单编号
     */
    @Excel(name = "订单编号")
    private String orderCode;

    /**
     * 销售订单编号
     */
    @Excel(name = "销售订单编号")
    private String saleOrderCode;

    /**
     * 销售订单行号
     */
    @Excel(name = "销售订单行号")
    private String saleOrderLineNumber;

    /**
     * 物料编码
     */
    @Excel(name = "物料编码")
    private String materialCode;

    /**
     * 物料名称
     */
    @Excel(name = "物料名称")
    private String materialName;

    /**
     * 物料组
     */
    @Excel(name = "物料组")
    private String matkl;

    /**
     * BOM编号
     */
    @Excel(name = "BOM编号")
    private String bomCode;

    /**
     * 订单计划数量
     */
    @Excel(name = "订单计划数量")
    private Long orderAmount;

    /**
     * 完成数量
     */
    @Excel(name = "完成数量")
    private Long completeAmount;

    /**
     * 工单类型
     */
    @Excel(name = "工单类型")
    private String orderType;

    /**
     * 工单状态（0未开始 1执行中 2执行完成 3取消）
     */
    @Excel(name = "工单状态", readConverterExp = "0=未开始,1=执行中,2=执行完成,3=取消")
    private String orderStatus;

    /**
     * 完成标识（0=正常，1=降级，2=超额）
     */
    @Excel(name = "完成标识", readConverterExp = "0==正常，1=降级，2=超额")
    private String finishFlag;

    /**
     * 计划开始时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "计划开始时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date beginDate;

    /**
     * 计划结束时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "计划结束时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date endDate;

    /**
     * 实际开始时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "实际开始时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date realBeginDate;

    /**
     * 实际完成时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "实际完成时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date realEndDate;

    /**
     * 工厂编号
     */
    @Excel(name = "工厂编号")
    private String factoryCode;

    /**
     * 是否已下达计划（0-是，1-否）
     */
    @Excel(name = "是否已下达计划", readConverterExp = "0=-是，1-否")
    private String isRelease;

    /**
     * 工作中心
     */
    @Excel(name = "工作中心")
    private String workCenterCode;

    /**
     * 工艺路线
     */
    @Excel(name = "工艺路线")
    private String routingCode;

    /**
     * 打印名称
     */
    @Excel(name = "打印名称")
    private String printName;

    /**
     * 预留标识
     */
    @Excel(name = "预留标识")
    private String isFlag;

    /**
     * 创建人
     */
    @Excel(name = "创建人")
    private String createdBy;

    /**
     * 创建时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "创建时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date createdTime;

    /**
     * 更新人
     */
    @Excel(name = "更新人")
    private String updatedBy;

    /**
     * 更新时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "更新时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date updatedTime;

    public void setObjId(Long objId) {
        this.objId = objId;
    }

    public Long getObjId() {
        return objId;
    }

    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }

    public String getOrderCode() {
        return orderCode;
    }

    public void setSaleOrderCode(String saleOrderCode) {
        this.saleOrderCode = saleOrderCode;
    }

    public String getSaleOrderCode() {
        return saleOrderCode;
    }

    public void setSaleOrderLineNumber(String saleOrderLineNumber) {
        this.saleOrderLineNumber = saleOrderLineNumber;
    }

    public String getSaleOrderLineNumber() {
        return saleOrderLineNumber;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMatkl(String matkl) {
        this.matkl = matkl;
    }

    public String getMatkl() {
        return matkl;
    }

    public void setBomCode(String bomCode) {
        this.bomCode = bomCode;
    }

    public String getBomCode() {
        return bomCode;
    }

    public void setOrderAmount(Long orderAmount) {
        this.orderAmount = orderAmount;
    }

    public Long getOrderAmount() {
        return orderAmount;
    }

    public void setCompleteAmount(Long completeAmount) {
        this.completeAmount = completeAmount;
    }

    public Long getCompleteAmount() {
        return completeAmount;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    public String getOrderStatus() {
        return orderStatus;
    }

    public void setFinishFlag(String finishFlag) {
        this.finishFlag = finishFlag;
    }

    public String getFinishFlag() {
        return finishFlag;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }

    public Date getBeginDate() {
        return beginDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setRealBeginDate(Date realBeginDate) {
        this.realBeginDate = realBeginDate;
    }

    public Date getRealBeginDate() {
        return realBeginDate;
    }

    public void setRealEndDate(Date realEndDate) {
        this.realEndDate = realEndDate;
    }

    public Date getRealEndDate() {
        return realEndDate;
    }

    public void setFactoryCode(String factoryCode) {
        this.factoryCode = factoryCode;
    }

    public String getFactoryCode() {
        return factoryCode;
    }

    public void setIsRelease(String isRelease) {
        this.isRelease = isRelease;
    }

    public String getIsRelease() {
        return isRelease;
    }

    public void setWorkCenterCode(String workCenterCode) {
        this.workCenterCode = workCenterCode;
    }

    public String getWorkCenterCode() {
        return workCenterCode;
    }

    public void setRoutingCode(String routingCode) {
        this.routingCode = routingCode;
    }

    public String getRoutingCode() {
        return routingCode;
    }

    public void setPrintName(String printName) {
        this.printName = printName;
    }

    public String getPrintName() {
        return printName;
    }

    public void setIsFlag(String isFlag) {
        this.isFlag = isFlag;
    }

    public String getIsFlag() {
        return isFlag;
    }

    public void setCreatedBy(String createdBy) {
        this.createdBy = createdBy;
    }

    public String getCreatedBy() {
        return createdBy;
    }

    public void setCreatedTime(Date createdTime) {
        this.createdTime = createdTime;
    }

    public Date getCreatedTime() {
        return createdTime;
    }

    public void setUpdatedBy(String updatedBy) {
        this.updatedBy = updatedBy;
    }

    public String getUpdatedBy() {
        return updatedBy;
    }

    public void setUpdatedTime(Date updatedTime) {
        this.updatedTime = updatedTime;
    }

    public Date getUpdatedTime() {
        return updatedTime;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("objId", getObjId())
                .append("orderCode", getOrderCode())
                .append("saleOrderCode", getSaleOrderCode())
                .append("saleOrderLineNumber", getSaleOrderLineNumber())
                .append("materialCode", getMaterialCode())
                .append("materialName", getMaterialName())
                .append("matkl", getMatkl())
                .append("bomCode", getBomCode())
                .append("orderAmount", getOrderAmount())
                .append("completeAmount", getCompleteAmount())
                .append("orderType", getOrderType())
                .append("orderStatus", getOrderStatus())
                .append("finishFlag", getFinishFlag())
                .append("beginDate", getBeginDate())
                .append("endDate", getEndDate())
                .append("realBeginDate", getRealBeginDate())
                .append("realEndDate", getRealEndDate())
                .append("factoryCode", getFactoryCode())
                .append("isRelease", getIsRelease())
                .append("workCenterCode", getWorkCenterCode())
                .append("routingCode", getRoutingCode())
                .append("printName", getPrintName())
                .append("isFlag", getIsFlag())
                .append("createdBy", getCreatedBy())
                .append("createdTime", getCreatedTime())
                .append("updatedBy", getUpdatedBy())
                .append("updatedTime", getUpdatedTime())
                .toString();
    }
}
