package com.os.mes.prod.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.os.common.exception.base.BaseException;
import com.os.common.utils.DateUtils;
import com.os.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.prod.mapper.ProdBomInfoMapper;
import com.os.mes.prod.domain.ProdBomInfo;
import com.os.mes.prod.service.IProdBomInfoService;

/**
 * 生产BOMService业务层处理
 *
 * @author Yinq
 * @date 2024-05-11
 */
@Service
public class ProdBomInfoServiceImpl implements IProdBomInfoService {
    @Autowired
    private ProdBomInfoMapper prodBomInfoMapper;

    /**
     * 查询生产BOM
     *
     * @param objId 生产BOM主键
     * @return 生产BOM
     */
    @Override
    public ProdBomInfo selectProdBomInfoByObjId(Long objId) {
        return prodBomInfoMapper.selectProdBomInfoByObjId(objId);
    }

    /**
     * 查询生产BOM列表
     *
     * @param prodBomInfo 生产BOM
     * @return 生产BOM
     */
    @Override
    public List<ProdBomInfo> selectProdBomInfoList(ProdBomInfo prodBomInfo) {
        return prodBomInfoMapper.selectProdBomInfoList(prodBomInfo);
    }

    /**
     * 查询生产BOM树列表
     * @param prodBomInfo
     * @return
     */
    @Override
    public List<ProdBomInfo> selectProductionBomTreeList(ProdBomInfo prodBomInfo) {
        List<ProdBomInfo> prodBomInfoList = new ArrayList<>();
        ProdBomInfo info = prodBomInfoMapper.selectProdBomInfoByObjId(prodBomInfo.getObjId());
        prodBomInfoList.add(info);
        try {
            ProdBomInfo bomInfo = new ProdBomInfo();
            bomInfo.setAncestors(info.getObjId().toString());
            List<ProdBomInfo> infos = prodBomInfoMapper.selectProdBomInfoList(bomInfo);
            prodBomInfoList.addAll(infos);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return prodBomInfoList;
    }

    /**
     * 新增生产BOM
     *
     * @param prodBomInfo 生产BOM
     * @return 结果
     */
    @Override
    public int insertProdBomInfo(ProdBomInfo prodBomInfo) {
        List<ProdBomInfo> baseBomInfos = prodBomInfoMapper.selectProdBomInfoList(prodBomInfo);
        if (baseBomInfos.size() > 0) {
            throw new BaseException("该物料编号：" + prodBomInfo.getMaterialCode() + "已存在！");
        }
        ProdBomInfo info = prodBomInfoMapper.selectProdBomInfoByObjId(prodBomInfo.getParentId());
        if (StringUtils.isNull(info)) {
            prodBomInfo.setAncestors(prodBomInfo.getParentId().toString());
        } else {
            prodBomInfo.setAncestors(info.getAncestors() + "," + prodBomInfo.getParentId());
        }
        prodBomInfo.setCreateTime(DateUtils.getNowDate());
        return prodBomInfoMapper.insertProdBomInfo(prodBomInfo);
    }

    /**
     * 修改生产BOM
     *
     * @param prodBomInfo 生产BOM
     * @return 结果
     */
    @Override
    public int updateProdBomInfo(ProdBomInfo prodBomInfo) {
        prodBomInfo.setUpdateTime(DateUtils.getNowDate());
        ProdBomInfo info = prodBomInfoMapper.selectProdBomInfoByObjId(prodBomInfo.getParentId());
        if (StringUtils.isNull(info)) {
            prodBomInfo.setAncestors(prodBomInfo.getParentId().toString());
        } else {
            prodBomInfo.setAncestors(info.getAncestors() + "," + prodBomInfo.getParentId());
        }
        return prodBomInfoMapper.updateProdBomInfo(prodBomInfo);
    }

    /**
     * 批量删除生产BOM
     *
     * @param objIds 需要删除的生产BOM主键
     * @return 结果
     */
    @Override
    public int deleteProdBomInfoByObjIds(Long[] objIds) {
        return prodBomInfoMapper.deleteProdBomInfoByObjIds(objIds);
    }

    /**
     * 删除生产BOM信息
     *
     * @param objId 生产BOM主键
     * @return 结果
     */
    @Override
    public int deleteProdBomInfoByObjId(Long objId) {
        return prodBomInfoMapper.deleteProdBomInfoByObjId(objId);
    }
}
